@@ -6,11 +6,18 @@
 #' @description This function is deprecated and only exists for backwards
 #'   backwards compatibility. The function you want to use is `forestry`.
 #' @param ... parameters which are passed directly to `forestry`
-#' @return A `forestry` object
 #' @export honestRF
 honestRF <- function(...) forestry(...)
 
 
+#' @title Honest Random Forest
+#' @description This function is deprecated and only exists for backwards
+#'   backwards compatibility. The function you want to use is `autoforestry`.
+#' @param ... parameters which are passed directly to `autoforestry`
+#' @export autohonestRF
+autohonestRF <- function(...) autoforestry(...)
+
+
 # -- Random Forest Constructor -------------------------------------------------
 #' @title forestry class
 #' @name forestry-class
