@@ -6,10 +6,10 @@
 #include <string>
 #include <random>
 #include <chrono>
-#include "dataFrame.h"
+#include "DataFrame.h"
 #include "RFNode.h"
 #include "utils.h"
-#include <armadillo>
+#include <RcppArmadillo.h>
 
 class forestryTree {
 
@@ -29,12 +29,10 @@ public:
     size_t interactionDepth,
     std::unique_ptr< std::vector<size_t> > splittingSampleIndex,
     std::unique_ptr< std::vector<size_t> > averagingSampleIndex,
-    std::unique_ptr< std::vector<size_t> > excludedSampleIndex,
     std::mt19937_64& random_number_generator,
     bool splitMiddle,
     size_t maxObs,
     bool hasNas,
-    bool naDirection,
     bool linear,
     double overfitPenalty,
     unsigned int seed
@@ -52,22 +50,17 @@ public:
     size_t interactionDepth,
     std::unique_ptr< std::vector<size_t> > splittingSampleIndex,
     std::unique_ptr< std::vector<size_t> > averagingSampleIndex,
-    std::unique_ptr< std::vector<size_t> > excludedSampleIndex,
     double overfitPenalty
   );
 
   void predict(
     std::vector<double> &outputPrediction,
     std::vector<int>* terminalNodes,
-    std::vector< std::vector<double> > &outputCoefficients,
     std::vector< std::vector<double> >* xNew,
     DataFrame* trainingData,
     arma::Mat<double>* weightMatrix = NULL,
     bool linear = false,
-    bool naDirection = false,
-    unsigned int seed = 44,
-    size_t nodesizeStrictAvg = 1,
-    std::vector<size_t>* OOBIndex = NULL
+    unsigned int seed = 44
   );
 
   std::unique_ptr<tree_info> getTreeInfo(
@@ -84,29 +77,26 @@ public:
       size_t maxDepth,
       size_t interactionDepth,
       bool hasNas,
-      bool naDirection,
       bool linear,
       double overfitPenalty,
-      unsigned int seed,
       std::vector<size_t> categoricalFeatureColsRcpp,
       std::vector<int> var_ids,
       std::vector<double> split_vals,
       std::vector<int> naLeftCounts,
       std::vector<int> naRightCounts,
-      std::vector<int> naDefaultDirections,
+      std::vector<size_t> leafAveidxs,
+      std::vector<size_t> leafSplidxs,
       std::vector<size_t> averagingSampleIndex,
-      std::vector<size_t> splittingSampleIndex,
-      std::vector<size_t> excludedSampleIndex,
-      std::vector<double> predictWeights);
+      std::vector<size_t> splittingSampleIndex);
 
   void recursive_reconstruction(
       RFNode* currentNode,
       std::vector<int> * var_ids,
       std::vector<double> * split_vals,
+      std::vector<size_t> * leafAveidxs,
+      std::vector<size_t> * leafSplidxs,
       std::vector<int> * naLeftCounts,
-      std::vector<int> * naRightCounts,
-      std::vector<int> * naDefaultDirections,
-      std::vector<double> * weights
+      std::vector<int> * naRightCounts
   );
 
   void recursivePartition(
@@ -123,32 +113,30 @@ public:
     std::shared_ptr< arma::Mat<double> > gtotal,
     std::shared_ptr< arma::Mat<double> > stotal,
     bool monotone_splits,
-    monotonic_info monotone_details,
-    bool naDirection
+    monotonic_info monotone_details
   );
 
   void selectBestFeature(
-      size_t &bestSplitFeature,
-      double &bestSplitValue,
-      double &bestSplitLoss,
-      int &bestSplitNaDir,
-      arma::Mat<double> &bestSplitGL,
-      arma::Mat<double> &bestSplitGR,
-      arma::Mat<double> &bestSplitSL,
-      arma::Mat<double> &bestSplitSR,
-      std::vector<size_t>* featureList,
-      std::vector<size_t>* averagingSampleIndex,
-      std::vector<size_t>* splittingSampleIndex,
-      DataFrame* trainingData,
-      std::mt19937_64& random_number_generator,
-      bool splitMiddle,
-      size_t maxObs,
-      bool linear,
-      double overfitPenalty,
-      std::shared_ptr< arma::Mat<double> > gtotal,
-      std::shared_ptr< arma::Mat<double> > stotal,
-      bool monotone_splits,
-      monotonic_info &monotone_details
+    size_t& bestSplitFeature,
+    double& bestSplitValue,
+    double& bestSplitLoss,
+    arma::Mat<double> &bestSplitGL,
+    arma::Mat<double> &bestSplitGR,
+    arma::Mat<double> &bestSplitSL,
+    arma::Mat<double> &bestSplitSR,
+    std::vector<size_t>* featureList,
+    std::vector<size_t>* averagingSampleIndex,
+    std::vector<size_t>* splittingSampleIndex,
+    DataFrame* trainingData,
+    std::mt19937_64& random_number_generator,
+    bool splitMiddle,
+    size_t maxObs,
+    bool linear,
+    double overfitPenalty,
+    std::shared_ptr< arma::Mat<double> > gtotal,
+    std::shared_ptr< arma::Mat<double> > stotal,
+    bool monotone_splits,
+    monotonic_info &monotone_details
   );
 
   void initializelinear(
@@ -165,46 +153,21 @@ public:
 
   void getOOBindex(
     std::vector<size_t> &outputOOBIndex,
-    std::vector<size_t> &allIndex
-  );
-
-  void getDoubleOOBIndex(
-      std::vector<size_t> &outputOOBIndex,
-      std::vector<size_t> &allIndex
-  );
-
-  void getOOBhonestIndex(
-      std::vector<size_t> &outputOOBIndex,
-      std::vector<size_t> &allIndex
-  );
-
-  void getDoubleOOBIndexExcluded(
-          std::vector<size_t> &outputOOBIndex,
-          std::vector<size_t> &allIndex
-  );
-
-  void getOOBIndexExcluded(
-          std::vector<size_t> &outputOOBIndex,
-          std::vector<size_t> &allIndex
-  );
-
-  void getOOGIndex(
-      std::vector<size_t> &outputOOBIndex,
-      std::vector<size_t> groupMemberships,
-      std::vector<size_t> &allIndex,
-      bool doubleOOB
+    size_t nRows
   );
 
   void getOOBPrediction(
     std::vector<double> &outputOOBPrediction,
     std::vector<size_t> &outputOOBCount,
-    DataFrame* trainingData,
-    bool OOBhonest,
-    bool doubleOOB,
-    size_t nodesizeStrictAvg,
-    std::vector< std::vector<double> >* xNew,
-    arma::Mat<double>* weightMatrix,
-    const std::vector<size_t>& training_idx
+    DataFrame* trainingData
+  );
+
+  void getShuffledOOBPrediction(
+      std::vector<double> &outputOOBPrediction,
+      std::vector<size_t> &outputOOBCount,
+      DataFrame* trainingData,
+      size_t shuffleFeature,
+      std::mt19937_64& random_number_generator
   );
 
   size_t getMtry() {
@@ -247,10 +210,6 @@ public:
     return _averagingSampleIndex.get();
   }
 
-  std::vector<size_t>* getExcludedIndex() {
-    return _excludedSampleIndex.get();
-  }
-
   RFNode* getRoot() {
     return _root.get();
   }
@@ -267,32 +226,14 @@ public:
     return _hasNas;
   }
 
-  bool getNaDirection() {
-    return _naDirection;
-  }
-
-  void assignNodeId(size_t& node_i,
-                    bool split) {
+  void assignNodeId(size_t& node_i) {
     node_i = ++_nodeCount;
-    if (split) {
-        _splitNodeCount++;
-    } else {
-        _leafNodeCount++;
-    }
   }
 
   size_t getNodeCount() {
     return _nodeCount;
   }
 
-  size_t getSplitNodeCount() {
-      return _splitNodeCount;
-  }
-
-  size_t getLeafNodeCount() {
-      return _leafNodeCount;
-  }
-
 private:
   size_t _mtry;
   size_t _minNodeSizeSpt;
@@ -304,16 +245,12 @@ private:
   size_t _interactionDepth;
   std::unique_ptr< std::vector<size_t> > _averagingSampleIndex;
   std::unique_ptr< std::vector<size_t> > _splittingSampleIndex;
-  std::unique_ptr< std::vector<size_t> > _excludedSampleIndex;
   std::unique_ptr< RFNode > _root;
   bool _hasNas;
-  bool _naDirection;
   bool _linear;
   double _overfitPenalty;
   unsigned int _seed;
   size_t _nodeCount;
-  size_t _splitNodeCount;
-  size_t _leafNodeCount;
 };
 
 
