@@ -20,8 +20,6 @@ multilayerForestry::multilayerForestry(
   bool replace,
   size_t sampSize,
   double splitRatio,
-  bool OOBhonest,
-  bool doubleBootstrap,
   size_t mtry,
   size_t minNodeSizeSpt,
   size_t minNodeSizeAvg,
@@ -45,8 +43,6 @@ multilayerForestry::multilayerForestry(
   this->_replace = replace;
   this->_sampSize = sampSize;
   this->_splitRatio = splitRatio;
-  this->_OOBhonest = OOBhonest;
-  this->_doubleBootstrap = doubleBootstrap;
   this->_mtry = mtry;
   this->_minNodeSizeAvg = minNodeSizeAvg;
   this->_minNodeSizeSpt = minNodeSizeSpt;
@@ -117,9 +113,6 @@ void multilayerForestry::addForests(size_t ntree) {
     std::unique_ptr< std::vector<int> > monotonicConstraintsRcpp_(
         new std::vector<int>(*(trainingData->getMonotonicConstraints()))
     );
-    std::unique_ptr< std::vector<size_t> > groupMembershipRcpp_(
-        new std::vector<size_t>(*(trainingData->getGroups()))
-    );
 
     DataFrame* residualDataFrame = new DataFrame(
       residualFeatureData_,
@@ -133,10 +126,7 @@ void multilayerForestry::addForests(size_t ntree) {
       std::move(residualdeepFeatureWeights_),
       std::move(residualdeepFeatureWeightsVariables_),
       std::move(residualobservationWeights_),
-      std::move(monotonicConstraintsRcpp_),
-      std::move(groupMembershipRcpp_),
-      false,
-      0
+      std::move(monotonicConstraintsRcpp_)
     );
 
     forestry *residualForest = new forestry(
@@ -145,8 +135,6 @@ void multilayerForestry::addForests(size_t ntree) {
       _replace,
       _sampSize,
       _splitRatio,
-      _OOBhonest,
-      _doubleBootstrap,
       _mtry,
       _minNodeSizeSpt,
       _minNodeSizeAvg,
@@ -160,11 +148,8 @@ void multilayerForestry::addForests(size_t ntree) {
       _verbose,
       _splitMiddle,
       _maxObs,
-      0, // We aren't giving minimum trees per groups, so set this to zero
-      1,
       false,  // This is hasNAs being set to false
       _linear,
-      false, // Set symmetric = FALSE
       _overfitPenalty,
       _doubleTree
     );
@@ -180,14 +165,10 @@ void multilayerForestry::addForests(size_t ntree) {
     // previous forests, the problem spirals out of control.
     std::unique_ptr< std::vector<double> > predictedResiduals =
       residualForest->predict(getTrainingData()->getAllFeatureData(),
-                              NULL,
                               NULL,
                               NULL,
                               _seed,
-                              1,
-                              false,
-                              false,
-                              NULL);
+                              1);
 
     // Calculate and store best gamma value
     // std::vector<double> bestPredictedResiduals(trainingData->getNumRows());
@@ -242,9 +223,7 @@ void multilayerForestry::addForests(size_t ntree) {
 std::unique_ptr< std::vector<double> > multilayerForestry::predict(
     std::vector< std::vector<double> >* xNew,
     arma::Mat<double>* weightMatrix,
-    int seed,
-    size_t nthread,
-    bool exact
+    int seed
 ) {
   std::vector< forestry* > multilayerForests = *getMultilayerForests();
   std::vector<double> gammas = getGammas();
@@ -256,12 +235,8 @@ std::unique_ptr< std::vector<double> > multilayerForestry::predict(
     multilayerForests[0]->predict(xNew,
                                   weightMatrix,
                                   NULL,
-                                  NULL,
                                   seed,
-                                  nthread,
-                                  exact,
-                                  false,
-                                  NULL);
+                                  this->getNthread());
 
   std::vector<double> prediction(initialPrediction->size(), getMeanOutcome());
 
@@ -277,12 +252,8 @@ std::unique_ptr< std::vector<double> > multilayerForestry::predict(
       multilayerForests[i]->predict(xNew,
                                     weightMatrix,
                                     NULL,
-                                    NULL,
                                     seed,
-                                    nthread,
-                                    exact,
-                                    false,
-                                    NULL);
+                                    this->getNthread());
 
     std::transform(predictedResiduals->begin(), predictedResiduals->end(),
                    predictedResiduals->begin(), std::bind(std::multiplies<double>(), gammas[i], std::placeholders::_1));
