@@ -12,17 +12,17 @@ test_that("Tests that compute the lp distances works correctly", {
   x_test <- iris[test_idx, -1]
 
   # Create a random forest
-  rf <- forestry(x = x_train, y = y_train, nthread = 1,scale=FALSE)
+  rf <- forestry(x = x_train, y = y_train, nthread = 1)
 
   # Compute the l1 distances in the "Species" dimension
   distances_1 <- compute_lp(object = rf,
-                            newdata = x_test,
+                            feature.new = x_test,
                             feature = "Species",
                             p = 1)
 
   # Compute the l2 distances in the "Petal.Length" dimension
   distances_2 <- compute_lp(object = rf,
-                            newdata = x_test,
+                            feature.new = x_test,
                             feature = "Petal.Length",
                             p = 2)
 
@@ -33,13 +33,14 @@ test_that("Tests that compute the lp distances works correctly", {
   skip_if_not_mac()
 
   expect_equal(distances_1,
-               c(0.00785714285714286, 0.19730952380952380, 0.00000000000000000, 0.01016666666666667, 0.01807380952380952,
-                 0.01933333333333333, 0.00686666666666667, 0.02375000000000000, 0.05970952380952381, 0.03026190476190477, 0.06266666666666666),
-               tolerance = 1e-10)
+               c(0.7412765, 0.5626915, 0.6670021, 0.4814331,
+                 0.4269154, 0.7936147, 0.6906481, 0.6000588,
+                 0.7773134, 0.5397050, 0.6732839),
+               tolerance = 1e-6)
   expect_equal(distances_2,
-               c(0.464027624082161, 0.479313427569380, 0.199483638581166, 0.359174919735252,
-                 0.502185731724906, 0.374985196507176, 0.421947452590307, 0.406795047600484,
-                 0.418917363075821, 0.373736732268053, 0.503685111790328),
-               tolerance = 1e-10)
+               c(2.372681, 2.497261, 2.704748, 1.900080,
+                 1.638488, 2.406346, 2.101205, 2.427264,
+                 3.078544, 2.412146, 2.297884),
+               tolerance = 1e-6)
 })
 
