@@ -15,12 +15,11 @@ test_that("Tests that Monotone splits parameter is working correctly", {
     ntree = 500,
     nodesizeStrictSpl = 5,
     maxDepth = 10,
-    nthread = 2,
     monotonicConstraints = c(1)
   )
   # Test predictions are monotonic increasing in the first feature
   pred_means <- sapply(c(1:9), function(x) {mean(predict(monotone_forest,
-                                                         newdata = data.frame(V1 = rep(x, 100))))})
+                                                         feature.new = data.frame(V1 = rep(x, 100))))})
 
   # Mean Square Error
   expect_equal(all.equal(order(pred_means), 1:9), TRUE)
@@ -32,12 +31,11 @@ test_that("Tests that Monotone splits parameter is working correctly", {
     ntree = 500,
     nodesizeStrictSpl = 3,
     maxDepth = 10,
-    nthread = 2,
     monotonicConstraints = c(-1)
   )
   # Test predictions are monotonic decreasing in the first feature
   pred_means <- sapply(c(1,3,5,9), function(x) {mean(predict(monotone_forest,
-                                                             newdata = data.frame(V1 = rep(x, 100))))})
+                                                             feature.new = data.frame(V1 = rep(x, 100))))})
 
   # Mean Square Error
   # expect_equal(all.equal(order(pred_means), 4:1), TRUE)
@@ -58,6 +56,6 @@ test_that("Tests that Monotone splits parameter is working correctly", {
                           nthread = 1,
                           ntree = 500)
 
-  preds <- predict(monotone_rf, newdata = data.frame(x1 = c(2, 7), x2 = c(4,4)))
+  preds <- predict(monotone_rf, feature.new = data.frame(x1 = c(2, 7), x2 = c(4,4)))
   expect_equal(preds[1] >= preds[2], TRUE)
 })
